EasyExtend.langlets.p4d.p4dbase.P4DName

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase :: Class P4DName |
[hide private]
[frames] | no frames]

# Class P4DName

    object --+
             |
    basestring --+
                 |
               str --+
                     |
                    P4DName

Instance Methods | [hide private]
__init__(self, tag, tagwrapper=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
_get_uri(self) |
_get_local_name(self) |
Inherited from `str`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__hash__`, `__le__`, `__len__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__new__`, `__repr__`, `__rmod__`, `__rmul__`, `__str__`, `capitalize`, `center`, `count`, `decode`, `encode`, `endswith`, `expandtabs`, `find`, `index`, `isalnum`, `isalpha`, `isdigit`, `islower`, `isspace`, `istitle`, `isupper`, `join`, `ljust`, `lower`, `lstrip`, `partition`, `replace`, `rfind`, `rindex`, `rjust`, `rpartition`, `rsplit`, `rstrip`, `split`, `splitlines`, `startswith`, `strip`, `swapcase`, `title`, `translate`, `upper`, `zfill` Inherited from `object`: `__delattr__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Properties | [hide private]
| uri
| local_name
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, tag, tagwrapper=None) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### uri Get Method: _get_uri(self)

### local_name Get Method: _get_local_name(self)